

set -ex



test -f $PREFIX/lib/libpdfium.so
test -f "${PREFIX}/include/fpdf_annot.h"
test -f "${PREFIX}/include/fpdf_attachment.h"
test -f "${PREFIX}/include/fpdf_catalog.h"
test -f "${PREFIX}/include/fpdf_dataavail.h"
test -f "${PREFIX}/include/fpdf_doc.h"
test -f "${PREFIX}/include/fpdf_edit.h"
test -f "${PREFIX}/include/fpdf_ext.h"
test -f "${PREFIX}/include/fpdf_flatten.h"
test -f "${PREFIX}/include/fpdf_formfill.h"
test -f "${PREFIX}/include/fpdf_fwlevent.h"
test -f "${PREFIX}/include/fpdf_javascript.h"
test -f "${PREFIX}/include/fpdf_ppo.h"
test -f "${PREFIX}/include/fpdf_progressive.h"
test -f "${PREFIX}/include/fpdf_save.h"
test -f "${PREFIX}/include/fpdf_searchex.h"
test -f "${PREFIX}/include/fpdf_signature.h"
test -f "${PREFIX}/include/fpdf_structtree.h"
test -f "${PREFIX}/include/fpdf_sysfontinfo.h"
test -f "${PREFIX}/include/fpdf_text.h"
test -f "${PREFIX}/include/fpdf_thumbnail.h"
test -f "${PREFIX}/include/fpdf_transformpage.h"
test -f "${PREFIX}/include/fpdfview.h"
exit 0
